summaryrefslogtreecommitdiffstats
path: root/tdecore/tdecmdlineargs.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/tdecmdlineargs.h')
-rw-r--r--tdecore/tdecmdlineargs.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/tdecore/tdecmdlineargs.h b/tdecore/tdecmdlineargs.h
index 013def801..fe97fa09c 100644
--- a/tdecore/tdecmdlineargs.h
+++ b/tdecore/tdecmdlineargs.h
@@ -69,7 +69,7 @@ struct TDECORE_EXPORT TDECmdLineOptions
class TDECmdLineArgsList;
class TDEApplication;
-class KUniqueApplication;
+class TDEUniqueApplication;
class TDECmdLineParsedOptions;
class TDECmdLineParsedArgs;
class TDEAboutData;
@@ -97,19 +97,19 @@ class TDECmdLineArgsPrivate;
* TDECmdLineArgs::addCmdLineOptions( options );
*
* // Add options from other components
- * KUniqueApplication::addCmdLineOptions();
+ * TDEUniqueApplication::addCmdLineOptions();
*
* ....
*
* // Create application object without passing 'argc' and 'argv' again.
- * KUniqueApplication app;
+ * TDEUniqueApplication app;
*
* ....
*
* // Handle our own options/arguments
* // A TDEApplication will usually do this in main but this is not
* // necessary.
* // A KUniqueApplication might want to handle it in newInstance().
*
* TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
*
@@ -222,7 +222,7 @@ class TDECmdLineArgsPrivate;
class TDECORE_EXPORT TDECmdLineArgs
{
friend class TDEApplication;
- friend class KUniqueApplication;
+ friend class TDEUniqueApplication;
friend class TQPtrList<TDECmdLineArgs>;
public:
// Static functions:
@@ -373,7 +373,7 @@ public:
* Get the CWD (Current Working Directory) associated with the
* current command line arguments.
*
* Typically this is needed in KUniqueApplication::newInstance()
* since the CWD of the process may be different from the CWD
* where the user started a second instance.
* @return the current working directory
@@ -606,7 +606,7 @@ private:
static void removeArgs(const char *id);
/**
* @internal for KUniqueApplication only:
*
* Save all but the Qt and KDE arguments to a stream.
*/
@@ -97,19 +97,19 @@ class TDECmdLineArgsPrivate;
* // A TDEApplication will usually do this in main but this is not
* // necessary.
- * // A KUniqueApplication might want to handle it in newInstance().
+ * // A TDEUniqueApplication might want to handle it in newInstance().
*
* TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
@@ -373,7 +373,7 @@ public:
* current command line arguments.
*
- * Typically this is needed in KUniqueApplication::newInstance()
+ * Typically this is needed in TDEUniqueApplication::newInstance()
* since the CWD of the process may be different from the CWD
* where the user started a second instance.
@@ -606,7 +606,7 @@ private:
static void removeArgs(const char *id);
/**
- * @internal for KUniqueApplication only:
+ * @internal for TDEUniqueApplication only:
*
* Save all but the Qt and KDE arguments to a stream.